@@ -30,7 +30,7 @@ def max_shape(shapes:[]):
             maxvol=vol
     return maxshape
 
-def max_shape_ndarray(lndarr:list[numpy.ndarray]):
+def max_shape_ndarray(lndarr:[numpy.ndarray]):
     maxshape=lndarr[0].shape
     maxvol=volume(maxshape)
     for ndarr in lndarr:
@@ -61,10 +61,10 @@ class NodeBase():
         self.nboutput = len(nodeproto.output)
         self.name = nodeproto.name
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         return 0,0
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         return [(0),]
 
 @NODEPROFILER_REGISTRY.register()
@@ -78,7 +78,7 @@ class Conv(NodeBase):
         self.dilations=(1,1)
         auto_add_attributes(nodeproto.attribute,validAttr,self)
 
-    def infer_shape(self,intensors: list[numpy.ndarray]):
+    def infer_shape(self,intensors: [numpy.ndarray]):
         outtensors=[]
         xtensor=intensors[0]
         wtensor=intensors[1]
@@ -104,7 +104,7 @@ class Conv(NodeBase):
         outtensors.append(create_ndarray_f32(shape))
         return outtensors
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         macs = 0
         params = 0
         if self.nboutput == 1:
@@ -137,7 +137,7 @@ class ConvTranspose(NodeBase):
         self.group=1
         auto_add_attributes(nodeproto.attribute,validAttr,self)
 
-    def infer_shape(self,intensors: list[numpy.ndarray]):
+    def infer_shape(self,intensors: [numpy.ndarray]):
         xtensor=intensors[0]
         wtensor=intensors[1]
         xshape=xtensor.shape
@@ -160,7 +160,7 @@ class ConvTranspose(NodeBase):
                 shape[2]=self.output_shape[0]
         return [create_ndarray_f32(shape)]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         macs = 0
         params = 0
         if self.nboutput == 1:
@@ -188,12 +188,12 @@ class PWNBase(NodeBase):
         self.op_mac=0
         self.ratio=max(1,self.nbinput-1)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         outtensors=[]
         outtensors.append(create_ndarray_f32(max_shape_ndarray(intensors)))
         return outtensors
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         macs = 0
         params = 0
 
@@ -206,7 +206,7 @@ class Add(PWNBase):
         super().__init__(nodeproto)
         self.op_mac=ADD_MACS
 
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         return [intensors[0]+intensors[1]]
 
 @NODEPROFILER_REGISTRY.register()
@@ -215,7 +215,7 @@ class Sum(PWNBase):
         super().__init__(nodeproto)
         self.op_mac=ADD_MACS
 
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         y=intensors[0]
         for i in range(1,len(intensors)):
             y=y+intensors[i]
@@ -227,7 +227,7 @@ class Abs(PWNBase):
         super().__init__(nodeproto)
         self.op_mac=CMP_MACS
 
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         return [numpy.abs(intensors[0])]
 
 @NODEPROFILER_REGISTRY.register()
@@ -236,7 +236,7 @@ class Neg(PWNBase):
         super().__init__(nodeproto)
         self.op_mac=CMP_MACS
 
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         return [-intensors[0]]
 
 @NODEPROFILER_REGISTRY.register()
@@ -245,7 +245,7 @@ class Sub(PWNBase):
         super().__init__(nodeproto)
         self.op_mac=ADD_MACS
 
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         return [intensors[0]-intensors[1]]
 
 
@@ -256,7 +256,7 @@ class Resize(NodeBase):
         attnames=['mode']
         auto_add_attributes(nodeproto.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         x=intensors[0]
         roi = []
         sizes = []
@@ -285,7 +285,7 @@ class Resize(NodeBase):
                 newshape = newshape.astype(dtype=numpy.int64)
         return [create_ndarray_f32(newshape)]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         macs=0
         outvol = volume(outtensors[0].shape)
         if self.mode == b'nearest':
@@ -318,7 +318,7 @@ def scatter_nd_impl(data, indices, updates, reduction='none'):  # type: ignore
 
 @NODEPROFILER_REGISTRY.register()
 class ScatterND(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         data=intensors[0]
         indices=intensors[1]
         updates=intensors[2]
@@ -339,7 +339,7 @@ class ArgMax(NodeBase):
         self.keepdims=1
         auto_add_attributes(n.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         data=intensors[0]
         return [argmax_use_numpy(data,self.axis,self.keepdims)]
 
@@ -352,7 +352,7 @@ class Expand(NodeBase):
     def __init__(self,nodeproto):
         super().__init__(nodeproto)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         input=intensors[0]
         shape=intensors[1]
         output=input*numpy.ones(shape.astype(numpy.int64),dtype=numpy.float32)
@@ -363,7 +363,7 @@ class Tile(NodeBase):
     def __init__(self,nodeproto):
         super().__init__(nodeproto)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         input=intensors[0]
         repeats=intensors[1]
         output=numpy.tile(input,repeats)
@@ -376,7 +376,7 @@ class GRU(NodeBase):
         attnames=['hidden_size']
         auto_add_attributes(nodeproto.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         x=intensors[0]
         w=intensors[1]
         seq_len=x.shape[0]
@@ -385,7 +385,7 @@ class GRU(NodeBase):
         h_len=w.shape[1]//3
         return [create_ndarray_f32((seq_len,num_dir,batch,h_len)),create_ndarray_f32((num_dir,batch,h_len))]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         w=intensors[1]
         r=intensors[2]
         b=intensors[3]
@@ -405,7 +405,7 @@ class LSTM(NodeBase):
         self.hidden_size=None
         auto_add_attributes(nodeproto.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         x=intensors[0]
         w=intensors[1]
         seq_len=x.shape[0]
@@ -414,7 +414,7 @@ class LSTM(NodeBase):
         h_len=w.shape[1]//4
         return [create_ndarray_f32((seq_len,num_dir,batch,h_len)),create_ndarray_f32((num_dir,batch,h_len))]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         w=intensors[1]
         r=intensors[2]
         b=intensors[3]
@@ -446,7 +446,7 @@ class PoolBase(NodeBase):
         self.op_mac=CMP_MACS
 
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         if len(self.kernel_shape)==1:
             inshape=intensors[0].shape
             outshape=inshape[:2]+(pooling_shape_calc(inshape[2],self.pads[0]+self.pads[1],self.kernel_shape[0],self.dilations[0],
@@ -462,7 +462,7 @@ class PoolBase(NodeBase):
             )
             return [create_ndarray_f32(outshape)]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         outvol = volume(outtensors[0].shape)
         macs = outvol*CMP_MACS*self.kernel_shape[0]
         if len(self.kernel_shape) == 2:
@@ -500,7 +500,7 @@ class ReduceMean(NodeBase):
         auto_add_attributes(nodeproto.attribute,attnames,self)
         self.axes=tuple(self.axes) if self.axes is not None else None
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         reduced=numpy.mean(intensors[0], axis=self.axes, keepdims=self.keepdims == 1)
         return [reduced]
         # inshape=intensors[0].shape
@@ -523,18 +523,18 @@ class ReduceMean(NodeBase):
         #             shape.append(inshape[i])
         # return [create_ndarray_f32(shape)]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         data=intensors[0]
         vol=volume(data.shape)
         return vol*ADD_MACS,0
 
 @NODEPROFILER_REGISTRY.register()
 class ReduceProd(ReduceMean):
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         reduced = numpy.prod(intensors[0], axis=self.axes, keepdims=self.keepdims == 1)
         return [reduced]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         data=intensors[0]
         vol=volume(data.shape)
         return vol*MUL_MACS,0
@@ -549,36 +549,36 @@ class ReduceL2(NodeBase):
         auto_add_attributes(nodeproto.attribute,attnames,self)
         self.axes=tuple(self.axes) if self.axes is not None else None
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         reduced=np.sqrt(numpy.sum(intensors[0], axis=self.axes, keepdims=self.keepdims == 1))
         return [reduced]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         data = intensors[0]
         vol = volume(data.shape)
         return vol * (ADD_MACS+SQRT_MACS), 0
 
 @NODEPROFILER_REGISTRY.register()
 class ReduceSum(ReduceMean):
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         reduced = numpy.sum(intensors[0], axis=self.axes, keepdims=self.keepdims == 1)
         return [reduced]
 
 @NODEPROFILER_REGISTRY.register()
 class ReduceMin(ReduceMean):
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         data=intensors[0]
         reduced=numpy.minimum.reduce(data, axis=self.axes, keepdims=self.keepdims == 1)
         return [reduced]
 
-    def profile(self, intensors: list[numpy.ndarray], outtensors: list[numpy.ndarray]):
+    def profile(self, intensors: [numpy.ndarray], outtensors: [numpy.ndarray]):
         data = intensors[0]
         vol = volume(data.shape)
         return vol * CMP_MACS, 0
 
 @NODEPROFILER_REGISTRY.register()
 class ReduceMax(ReduceMin):
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         data=intensors[0]
         reduced=numpy.maximum.reduce(data, axis=self.axes, keepdims=self.keepdims == 1)
         return [reduced]
@@ -592,7 +592,7 @@ class ReduceMax(ReduceMin):
 #         attnames = ['axis', 'keepdims']
 #         auto_add_attributes(nodeproto.attribute, attnames, self)
 #
-#     def infer_shape(self,intensors:list[numpy.ndarray]):
+#     def infer_shape(self,intensors:[numpy.ndarray]):
 #         newshape=[]
 #         ndim=len(intensors[0].shape)
 #         self.axis=axes_neg2pos(ndim,[self.axis])[0]
@@ -613,7 +613,7 @@ class Scan(NodeBase):
         attnames = ['num_scan_inputs', 'scan_input_directions']
         auto_add_attributes(nodeproto.attribute, attnames, self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         #TODO
         return [create_ndarray_f32((1,1)),create_ndarray_f32((1,1)),create_ndarray_f32((1,)),
                 intensors[3],intensors[3],]
@@ -626,12 +626,12 @@ class Compress(NodeBase):
         attnames=['axis']
         auto_add_attributes(node.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         return [numpy.compress(intensors[1],intensors[0],self.axis)]
 
 @NODEPROFILER_REGISTRY.register()
 class NonZero(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         condi=intensors[0]
         result=numpy.array(numpy.nonzero(condi),dtype=numpy.int64)
         if volume(result.shape)==0:
@@ -639,33 +639,33 @@ class NonZero(NodeBase):
             result=numpy.array(numpy.nonzero(condi),dtype=numpy.int64)
         return [result]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         return volume(outtensors[0].shape)*CMP_MACS,0
 
 @NODEPROFILER_REGISTRY.register()
 class Less(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         result=numpy.less(intensors[0],intensors[1])
         return [result]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         return volume(outtensors[0].shape)*CMP_MACS,0
 
 @NODEPROFILER_REGISTRY.register()
 class LessOrEqual(Less):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         result=numpy.less_equal(intensors[0],intensors[1])
         return [result]
 
 @NODEPROFILER_REGISTRY.register()
 class Not(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         result=numpy.logical_not(intensors[0].astype(numpy.bool))
         return [result]
 
 @NODEPROFILER_REGISTRY.register()
 class And(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         result=numpy.logical_and(intensors[0].astype(numpy.bool),intensors[1].astype(numpy.bool))
         return [result]
 
@@ -676,7 +676,7 @@ class Min(PWNBase):
         self.op_mac=CMP_MACS
         self.ratio=self.nbinput-1
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         result=intensors[0]
         for i in range(1,self.nbinput):
             result=numpy.minimum(result,intensors[i])
@@ -684,14 +684,14 @@ class Min(PWNBase):
 
 @NODEPROFILER_REGISTRY.register()
 class Where(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         result=numpy.where(intensors[0],intensors[1],intensors[2])
         return [result]
 
 
 @NODEPROFILER_REGISTRY.register()
 class Max(Min):
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         result = intensors[0]
         for i in range(1, self.nbinput):
             result = numpy.maximum(result, intensors[i])
@@ -700,13 +700,13 @@ class Max(Min):
 
 @NODEPROFILER_REGISTRY.register()
 class Equal(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         result=numpy.equal(intensors[0],intensors[1])
         return [result]
 
 @NODEPROFILER_REGISTRY.register()
 class Greater(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         result=numpy.greater(intensors[0],intensors[1])
         return [result]
 
@@ -717,7 +717,7 @@ class RoiAlign(NodeBase):
         attnames=['mode','output_height','output_width','sampling_ratio','spatial_scale']
         auto_add_attributes(node.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         x=intensors[0]
         if len(x.shape)==4 and self.output_height is not None and self.output_width is not None:
             newshape=x.shape[:2]+(self.output_height,self.output_width)
@@ -744,20 +744,20 @@ def scatter_elements(data, indices, updates, axis=0, reduction='none'):  # type:
         return unpacked
 
     def make_indices_for_duplicate(idx):  # type: ignore
-        final_idx = list()
+        final_idx = ()
         for i in range(len(idx[0])):
             final_idx.append(tuple(idx_element[i] for idx_element in idx))
-        return list(final_idx)
+        return (final_idx)
 
     # We use indices and axis parameters to create idx
     # idx is in a form that can be used as a NumPy advanced indices for scattering of updates param. in data
     idx = [[unpack(np.indices(idx_xsection_shape).reshape(indices.ndim - 1, -1)),
             indices[tuple(make_slice(indices, axis, i))].reshape(1, -1)[0]] for i in range(indices.shape[axis])]
-    idx = list(np.concatenate(idx, axis=1))
+    idx = (np.concatenate(idx, axis=1))
     idx.insert(axis, idx.pop())
 
     # updates_idx is a NumPy advanced indices for indexing of elements in the updates
-    updates_idx = list(idx)
+    updates_idx = (idx)
     updates_idx.pop(axis)
     updates_idx.insert(axis, np.repeat(np.arange(indices.shape[axis]), np.prod(idx_xsection_shape)))
 
@@ -780,7 +780,7 @@ class ScatterElements(NodeBase):
         attnames=['axis']
         auto_add_attributes(node.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         #TODO
         # y = scatter_elements(intensors[0], intensors[1], intensors[2], self.axis)
         # return [create_ndarray_f32(y)]
@@ -792,7 +792,7 @@ class Hardmax(PWNBase):
 
 @NODEPROFILER_REGISTRY.register()
 class GlobalAveragePool(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         outtensors=[]
         inshape=intensors[0].shape
         shape = inshape[0:2]
@@ -802,7 +802,7 @@ class GlobalAveragePool(NodeBase):
         outtensors.append(create_ndarray_f32(shape))
         return outtensors
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         macs = 0
         params = 0
         macs += volume(intensors[0].shape)*ADD_MACS+volume(outtensors[0].shape)*DIV_MACS
@@ -822,7 +822,7 @@ class TopK(NodeBase):
         self.axis=None
         auto_add_attributes(node.attribute,names,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         x=intensors[0]
         k=intensors[1][0]
         newshape=[]
@@ -867,7 +867,7 @@ class LRN(PWNBase):
             if att.name == 'size':
                 self.size = att.i
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         macs=0
         params=0
         outvol = volume(outtensors[0].shape)
@@ -885,7 +885,7 @@ class Gemm(NodeBase):
         self.transB=None
         auto_add_attributes(nodeproto.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         x = intensors[0]
         w = intensors[1]
 
@@ -903,7 +903,7 @@ class Gemm(NodeBase):
 
         return [create_ndarray_f32(yshape)]
 
-    def profile(self,intensors:list[numpy.ndarray],outtensors:list[numpy.ndarray]):
+    def profile(self,intensors:[numpy.ndarray],outtensors:[numpy.ndarray]):
         macs=0
         params=0
         xshape=intensors[0].shape
@@ -931,7 +931,7 @@ class MatMul(Gemm):
 
 @NODEPROFILER_REGISTRY.register()
 class Shape(NodeBase):
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         outtensors=[]
         outtensors.append(numpy.array(intensors[0].shape,numpy.int32))
         return outtensors
@@ -946,7 +946,7 @@ class Gather(NodeBase):
             if att.name=='axis':
                 self.axis=att.i
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         outtensors=[]
         out=numpy.take(intensors[0],intensors[1].astype(dtype=numpy.int),axis=self.axis)
         outtensors.append(out)
@@ -962,7 +962,7 @@ class Constant(NodeBase):
             if att.name == 'value':
                 self.value=get_attribute_data(att)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         return [self.value]
 
 
@@ -975,7 +975,7 @@ class Unsqueeze(NodeBase):
             if att.name == 'axes':
                 self.axes = get_attribute_data(att)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         outtensor=intensors[0]
         for axis in self.axes:
             outtensor=numpy.expand_dims(outtensor,axis=axis)
@@ -990,7 +990,7 @@ class Squeeze(NodeBase):
             if att.name == 'axes':
                 self.axes = get_attribute_data(att)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         outtensor=intensors[0]
         idx=0
         if self.nbinput==2:
@@ -1009,7 +1009,7 @@ class Concat(NodeBase):
             if att.name == 'axis':
                 self.axis = get_attribute_data(att)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         outtensor=numpy.concatenate(intensors,self.axis)
         return [outtensor]
 
@@ -1019,7 +1019,7 @@ class Reshape(NodeBase):
     def __init__(self,nodeproto):
         super().__init__(nodeproto)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         srcshape=intensors[0].shape
         shape=intensors[1]
         newshape=[]
@@ -1057,7 +1057,7 @@ class OneHot(NodeBase):
         self.axis=-1
         auto_add_attributes(nodeproto.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         indices=intensors[0]
         depth=intensors[1]
         values=intensors[2]
@@ -1067,7 +1067,7 @@ class OneHot(NodeBase):
 @NODEPROFILER_REGISTRY.register()
 class NonMaxSuppression(NodeBase):
     #TODO
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         if self.nbinput>=3:
             max_output_boxes_per_class=int(intensors[2][0])
             return [numpy.zeros((max_output_boxes_per_class,3),dtype=numpy.int)]
@@ -1079,7 +1079,7 @@ class FusedNode(NodeBase):
     def __init__(self, node_proto):
         super().__init__(node_proto)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         return [intensors[0]]
 
 @NODEPROFILER_REGISTRY.register()
@@ -1103,7 +1103,7 @@ class Pad(NodeBase):
         self.value=0
         auto_add_attributes(nodeproto.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         data=intensors[0]
         newshape=[]
         if self.pads is None:
@@ -1126,7 +1126,7 @@ class Split(NodeBase):
         self.split=None
         auto_add_attributes(nodeproto.attribute, attnames, self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         split=[]
         end=0
         if self.split is None:
@@ -1148,7 +1148,7 @@ class Transpose(NodeBase):
         auto_add_attributes(nodeproto.attribute,attnames,self)
 
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         return [numpy.transpose(intensors[0],self.perm)]
 
 @NODEPROFILER_REGISTRY.register()
@@ -1159,7 +1159,7 @@ class ConstantOfShape(NodeBase):
         self.value=None
         auto_add_attributes(nodeproto.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         arr=numpy.zeros(intensors[0].astype(numpy.int64),dtype=numpy.float32)
         if self.value is not None and len(self.value)==1:
             arr.fill(self.value[0])
@@ -1177,7 +1177,7 @@ class Slice(FusedNode):
         attnames=['axes','ends','starts']
         auto_add_attributes(nodeproto.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         if len(intensors)==3:
             data=intensors[0]
             starts=intensors[1]
@@ -1241,7 +1241,7 @@ class Slice(FusedNode):
 
 @NODEPROFILER_REGISTRY.register()
 class Cast(FusedNode):
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         return [intensors[0]]
 
 @NODEPROFILER_REGISTRY.register()
@@ -1252,7 +1252,7 @@ class Flatten(NodeBase):
         self.axis=None
         auto_add_attributes(node.attribute,attnames,self)
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         if self.axis is None:
             return [intensors[0].reshape((intensors[0].shape[0],-1))]
         else:
@@ -1307,7 +1307,7 @@ class Mul(PWNBase):
         super().__init__(node_proto)
         self.op_mac=MUL_MACS
 
-    def infer_shape(self,intensors:list[numpy.ndarray]):
+    def infer_shape(self,intensors:[numpy.ndarray]):
         return [intensors[0]*intensors[1]]
 
 @NODEPROFILER_REGISTRY.register()
@@ -1340,7 +1340,7 @@ class Div(PWNBase):
         super().__init__(node_proto)
         self.op_mac=DIV_MACS
 
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         return [intensors[0]/(intensors[1])]
 
 @NODEPROFILER_REGISTRY.register()
@@ -1349,7 +1349,7 @@ class Range(PWNBase):
         super().__init__(node_proto)
         self.op_mac=1
 
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         start=intensors[0]
         limit=intensors[1]
         delta=intensors[2]
@@ -1357,12 +1357,12 @@ class Range(PWNBase):
 
 @NODEPROFILER_REGISTRY.register()
 class Floor(FusedNode):
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         return [numpy.floor(intensors[0])]
 
 @NODEPROFILER_REGISTRY.register()
 class Ceil(FusedNode):
-    def infer_shape(self, intensors: list[numpy.ndarray]):
+    def infer_shape(self, intensors: [numpy.ndarray]):
         return [numpy.ceil(intensors[0])]
 
 @NODEPROFILER_REGISTRY.register()
